@@ -1,5 +1,5 @@
 from motion.trigger import Trigger
-from motion.schema import Schema, MEnum
+from motion.schema import Schema
 from motion.entry import (
     init,
     serve,
@@ -8,6 +8,7 @@ from motion.entry import (
     create_token,
     create_app,
     create_example_app,
+    get_logs,
 )
 from motion.routing import Route
 from motion.utils import update_params
@@ -16,7 +17,6 @@ from motion.cursor import Cursor
 from motion.utils import TriggerElement
 
 __all__ = [
-    "MEnum",
     "Schema",
     "Trigger",
     "init",
@@ -31,4 +31,5 @@ __all__ = [
     "create_example_app",
     "Cursor",
     "TriggerElement",
+    "get_logs",
 ]
